@@ -1,8 +1,9 @@
 #include "cpr/curlholder.h"
+#include "cpr/secure_string.h"
 #include <cassert>
 #include <curl/curl.h>
 #include <curl/easy.h>
-#include <string>
+#include <string_view>
 
 namespace cpr {
 CurlHolder::CurlHolder() {
@@ -28,22 +29,22 @@ CurlHolder::~CurlHolder() {
     curl_easy_cleanup(handle);
 }
 
-std::string CurlHolder::urlEncode(const std::string& s) const {
+util::SecureString CurlHolder::urlEncode(std::string_view s) const {
     assert(handle);
-    char* output = curl_easy_escape(handle, s.c_str(), static_cast<int>(s.length()));
+    char* output = curl_easy_escape(handle, s.data(), static_cast<int>(s.length()));
     if (output) {
-        std::string result = output;
+        util::SecureString result = output;
         curl_free(output);
         return result;
     }
     return "";
 }
 
-std::string CurlHolder::urlDecode(const std::string& s) const {
+util::SecureString CurlHolder::urlDecode(std::string_view s) const {
     assert(handle);
-    char* output = curl_easy_unescape(handle, s.c_str(), static_cast<int>(s.length()), nullptr);
+    char* output = curl_easy_unescape(handle, s.data(), static_cast<int>(s.length()), nullptr);
     if (output) {
-        std::string result = output;
+        util::SecureString result = output;
         curl_free(output);
         return result;
     }
