@@ -1,5 +1,6 @@
 #include "cpr/session.h"
 
+#include <array>
 #include <atomic>
 #include <cassert>
 #include <cstdint>
@@ -11,6 +12,8 @@
 #include <optional>
 #include <stdexcept>
 #include <string>
+#include <string_view>
+#include <type_traits>
 #include <utility>
 #include <variant>
 #include <vector>
@@ -25,6 +28,7 @@
 #include "cpr/auth.h"
 #include "cpr/bearer.h"
 #include "cpr/body.h"
+#include "cpr/body_view.h"
 #include "cpr/callback.h"
 #include "cpr/connect_timeout.h"
 #include "cpr/cookies.h"
@@ -120,8 +124,8 @@ void Session::prepareProxy() {
     if (proxies_.has(protocol)) {
         curl_easy_setopt(curl_->handle, CURLOPT_PROXY, proxies_[protocol].c_str());
         if (proxyAuth_.has(protocol)) {
-            curl_easy_setopt(curl_->handle, CURLOPT_PROXYUSERNAME, proxyAuth_.GetUsername(protocol));
-            curl_easy_setopt(curl_->handle, CURLOPT_PROXYPASSWORD, proxyAuth_.GetPassword(protocol));
+            curl_easy_setopt(curl_->handle, CURLOPT_PROXYUSERNAME, proxyAuth_.GetUsernameUnderlying(protocol).c_str());
+            curl_easy_setopt(curl_->handle, CURLOPT_PROXYPASSWORD, proxyAuth_.GetPasswordUnderlying(protocol).c_str());
         }
     }
 }
@@ -185,6 +189,16 @@ void Session::prepareCommonShared() {
     // Proxy:
     prepareProxy();
 
+    // handle NO_PROXY override passed through Proxies object
+    // Example: Proxies{"no_proxy": ""} will override environment variable definition with an empty list
+    const std::array<std::string, 2> no_proxy{"no_proxy", "NO_PROXY"};
+    for (const auto& item : no_proxy) { // cppcheck-suppress useStlAlgorithm
+        if (proxies_.has(item)) {       // cppcheck-suppress useStlAlgorithm
+            curl_easy_setopt(curl_->handle, CURLOPT_NOPROXY, proxies_[item].c_str());
+            break;
+        }
+    }
+
 #if LIBCURL_VERSION_NUM >= 0x071506 // 7.21.6
     if (acceptEncoding_.empty()) {
         // Enable all supported built-in compressions
@@ -278,6 +292,10 @@ void Session::RemoveContent() {
             curl_mime_free(curl_->multipart);
             curl_->multipart = nullptr;
         }
+    } else if (std::holds_alternative<cpr::BodyView>(content_)) {
+        // set default values, so curl does not send a body in subsequent requests
+        curl_easy_setopt(curl_->handle, CURLOPT_POSTFIELDSIZE_LARGE, -1);
+        curl_easy_setopt(curl_->handle, CURLOPT_POSTFIELDS, nullptr);
     }
     content_ = std::monostate{};
 }
@@ -398,6 +416,14 @@ void Session::SetAuth(const Authentication& auth) {
             curl_easy_setopt(curl_->handle, CURLOPT_HTTPAUTH, CURLAUTH_NEGOTIATE);
             curl_easy_setopt(curl_->handle, CURLOPT_USERPWD, auth.GetAuthString());
             break;
+        case AuthMode::ANY:
+            curl_easy_setopt(curl_->handle, CURLOPT_HTTPAUTH, CURLAUTH_ANY);
+            curl_easy_setopt(curl_->handle, CURLOPT_USERPWD, auth.GetAuthString());
+            break;
+        case AuthMode::ANYSAFE:
+            curl_easy_setopt(curl_->handle, CURLOPT_HTTPAUTH, CURLAUTH_ANYSAFE);
+            curl_easy_setopt(curl_->handle, CURLOPT_USERPWD, auth.GetAuthString());
+            break;
     }
 }
 
@@ -469,9 +495,15 @@ void Session::SetBody(Body&& body) {
     content_ = std::move(body);
 }
 
+// cppcheck-suppress passedByValue
+void Session::SetBodyView(BodyView body) {
+    static_assert(std::is_trivially_copyable_v<BodyView>, "BodyView expected to be trivially copyable otherwise will need some std::move across codebase");
+    content_ = body;
+}
+
 void Session::SetLowSpeed(const LowSpeed& low_speed) {
-    curl_easy_setopt(curl_->handle, CURLOPT_LOW_SPEED_LIMIT, low_speed.limit);
-    curl_easy_setopt(curl_->handle, CURLOPT_LOW_SPEED_TIME, low_speed.time); // cppcheck-suppress y2038-unsafe-call
+    curl_easy_setopt(curl_->handle, CURLOPT_LOW_SPEED_LIMIT, static_cast<long>(low_speed.limit));
+    curl_easy_setopt(curl_->handle, CURLOPT_LOW_SPEED_TIME, static_cast<long>(low_speed.time.count())); // cppcheck-suppress y2038-unsafe-call
 }
 
 void Session::SetVerifySsl(const VerifySsl& verify) {
@@ -575,7 +607,7 @@ void Session::SetSslOptions(const SslOptions& options) {
     }
 #if SUPPORT_TLSv13_CIPHERS
     if (!options.tls13_ciphers.empty()) {
-        curl_easy_setopt(curl_->handle, CURLOPT_TLS13_CIPHERS, options.ciphers.c_str());
+        curl_easy_setopt(curl_->handle, CURLOPT_TLS13_CIPHERS, options.tls13_ciphers.c_str());
     }
 #endif
 #if SUPPORT_SESSIONID_CACHE
@@ -640,6 +672,11 @@ void Session::SetHttpVersion(const HttpVersion& version) {
             curl_easy_setopt(curl_->handle, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_3);
             break;
 #endif
+#if LIBCURL_VERSION_NUM >= 0x075701 // 7.87.1, but corresponds to 7.88.0 tag
+        case HttpVersionCode::VERSION_3_0_ONLY:
+            curl_easy_setopt(curl_->handle, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_3ONLY);
+            break;
+#endif
 
         default: // Should not happen
             throw std::invalid_argument("Invalid/Unknown HTTP version type.");
@@ -918,7 +955,7 @@ const std::optional<Response> Session::intercept() {
     if (current_interceptor_ == interceptors_.end()) {
         current_interceptor_ = first_interceptor_;
     } else {
-        current_interceptor_++;
+        ++current_interceptor_;
     }
 
     if (current_interceptor_ != interceptors_.end()) {
@@ -947,6 +984,11 @@ void Session::prepareBodyPayloadOrMultipart() const {
         const std::string& body = std::get<cpr::Body>(content_).str();
         curl_easy_setopt(curl_->handle, CURLOPT_POSTFIELDSIZE_LARGE, static_cast<curl_off_t>(body.length()));
         curl_easy_setopt(curl_->handle, CURLOPT_COPYPOSTFIELDS, body.c_str());
+    } else if (std::holds_alternative<cpr::BodyView>(content_)) {
+        const std::string_view body = std::get<cpr::BodyView>(content_).str();
+        curl_easy_setopt(curl_->handle, CURLOPT_POSTFIELDSIZE_LARGE, static_cast<curl_off_t>(body.length()));
+        // NOLINTNEXTLINE (bugprone-suspicious-stringview-data-usage)
+        curl_easy_setopt(curl_->handle, CURLOPT_POSTFIELDS, body.data());
     } else if (std::holds_alternative<cpr::Multipart>(content_)) {
         // Make sure, we have a empty multipart to start with:
         if (curl_->multipart) {
@@ -996,7 +1038,7 @@ void Session::prepareBodyPayloadOrMultipart() const {
 }
 
 [[nodiscard]] bool Session::hasBodyOrPayload() const {
-    return std::holds_alternative<cpr::Body>(content_) || std::holds_alternative<cpr::Payload>(content_);
+    return std::holds_alternative<cpr::Body>(content_) || std::holds_alternative<cpr::BodyView>(content_) || std::holds_alternative<cpr::Payload>(content_);
 }
 
 // clang-format off
@@ -1033,6 +1075,8 @@ void Session::SetOption(const Redirect& redirect) { SetRedirect(redirect); }
 void Session::SetOption(const Cookies& cookies) { SetCookies(cookies); }
 void Session::SetOption(const Body& body) { SetBody(body); }
 void Session::SetOption(Body&& body) { SetBody(std::move(body)); }
+// cppcheck-suppress passedByValue
+void Session::SetOption(BodyView body) { SetBodyView(body); }
 void Session::SetOption(const LowSpeed& low_speed) { SetLowSpeed(low_speed); }
 void Session::SetOption(const VerifySsl& verify) { SetVerifySsl(verify); }
 void Session::SetOption(const Verbose& verbose) { SetVerbose(verbose); }
