@@ -4,23 +4,21 @@
 #include <string>
 #include <string_view>
 
+#include "cpr/util.h"
+
 namespace cpr {
 
-enum class AuthMode { BASIC, DIGEST, NTLM, NEGOTIATE };
+enum class AuthMode { BASIC, DIGEST, NTLM, NEGOTIATE, ANY, ANYSAFE };
 
 class Authentication {
   public:
     Authentication(std::string_view username, std::string_view password, AuthMode auth_mode);
-    Authentication(const Authentication& other) = default;
-    ~Authentication() noexcept;
-
-    Authentication& operator=(const Authentication& other) = default;
 
     const char* GetAuthString() const noexcept;
     AuthMode GetAuthMode() const noexcept;
 
   private:
-    std::string auth_string_;
+    util::SecureString auth_string_;
     AuthMode auth_mode_;
 };
 
