@@ -6,7 +6,10 @@
 #include <mutex>
 #include <string>
 
+#include "cpr/secure_string.h"
+
 namespace cpr {
+
 struct CurlHolder {
   private:
     /**
@@ -41,12 +44,12 @@ struct CurlHolder {
     /**
      * Uses curl_easy_escape(...) for escaping the given string.
      **/
-    [[nodiscard]] std::string urlEncode(const std::string& s) const;
+    [[nodiscard]] util::SecureString urlEncode(std::string_view s) const;
 
     /**
      * Uses curl_easy_unescape(...) for unescaping the given string.
      **/
-    [[nodiscard]] std::string urlDecode(const std::string& s) const;
+    [[nodiscard]] util::SecureString urlDecode(std::string_view s) const;
 };
 } // namespace cpr
 
