@@ -59,14 +59,14 @@ TEST(ErrorTests, ChronoConnectTimeoutFailure) {
 
 TEST(ErrorTests, LowSpeedTimeFailure) {
     Url url{server->GetBaseUrl() + "/low_speed.html"};
-    Response response = cpr::Get(url, cpr::LowSpeed{1000, 1});
+    Response response = cpr::Get(url, cpr::LowSpeed{1000, std::chrono::seconds(1)});
     // Do not check for the HTTP status code, since libcurl always provides the status code of the header if it was received
     EXPECT_EQ(ErrorCode::OPERATION_TIMEDOUT, response.error.code);
 }
 
 TEST(ErrorTests, LowSpeedBytesFailure) {
     Url url{server->GetBaseUrl() + "/low_speed_bytes.html"};
-    Response response = cpr::Get(url, cpr::LowSpeed{1000, 1});
+    Response response = cpr::Get(url, cpr::LowSpeed{1000, std::chrono::seconds(1)});
     // Do not check for the HTTP status code, since libcurl always provides the status code of the header if it was received
     EXPECT_EQ(ErrorCode::OPERATION_TIMEDOUT, response.error.code);
 }
@@ -91,6 +91,19 @@ TEST(ErrorTests, BoolTrueTest) {
     EXPECT_TRUE(error);
 }
 
+TEST(ErrorTests, StringReprTest) {
+    Error error;
+    error.code = ErrorCode::UNSUPPORTED_PROTOCOL;
+    EXPECT_EQ(std::to_string(error.code), "UNSUPPORTED_PROTOCOL");
+}
+
+TEST(ErrorTests, StringReprUnknownTest) {
+    Error error;
+    error.code = ErrorCode::UNKNOWN_ERROR;
+    EXPECT_EQ(std::to_string(error.code), "UNKNOWN_ERROR");
+}
+
+
 int main(int argc, char** argv) {
     ::testing::InitGoogleTest(&argc, argv);
     ::testing::AddGlobalTestEnvironment(server);
