@@ -13,6 +13,7 @@
 
 #include "cpr/accept_encoding.h"
 #include "httpServer.hpp"
+#include "testUtils.hpp"
 
 using namespace cpr;
 using namespace std::chrono_literals;
@@ -591,7 +592,7 @@ TEST(LowSpeedTests, SetLowSpeedTest) {
     Url url{server->GetBaseUrl() + "/hello.html"};
     Session session;
     session.SetUrl(url);
-    session.SetLowSpeed({1, 1});
+    session.SetLowSpeed({1, std::chrono::seconds(1)});
     Response response = session.Get();
     std::string expected_text{"Hello world!"};
     EXPECT_EQ(expected_text, response.text);
@@ -724,6 +725,23 @@ TEST(BodyTests, SetBodyValueTest) {
     EXPECT_EQ(ErrorCode::OK, response.error.code);
 }
 
+TEST(BodyTests, SetBodyViewTest) {
+    const Url url{server->GetBaseUrl() + "/url_post.html"};
+    Session session;
+    session.SetUrl(url);
+    session.SetBodyView(BodyView{"x=5"});
+    Response response = session.Post();
+    const std::string expected_text{
+            "{\n"
+            "  \"x\": 5\n"
+            "}"};
+    EXPECT_EQ(expected_text, response.text);
+    EXPECT_EQ(url, response.url);
+    EXPECT_EQ(std::string{"application/json"}, response.header["content-type"]);
+    EXPECT_EQ(201, response.status_code);
+    EXPECT_EQ(ErrorCode::OK, response.error.code);
+}
+
 TEST(DigestTests, SetDigestTest) {
     Url url{server->GetBaseUrl() + "/digest_auth.html"};
     Session session;
@@ -738,6 +756,49 @@ TEST(DigestTests, SetDigestTest) {
     EXPECT_EQ(ErrorCode::OK, response.error.code);
 }
 
+TEST(AnyAuthTests, SetAnyTest) {
+    Url url{server->GetBaseUrl() + "/digest_auth.html"};
+    Session session;
+    session.SetUrl(url);
+    session.SetAuth({"user", "password", AuthMode::ANY});
+    Response response = session.Get();
+    std::string expected_text{"Header reflect GET"};
+    EXPECT_EQ(expected_text, response.text);
+    EXPECT_EQ(url, response.url);
+    EXPECT_EQ(std::string{"text/html"}, response.header["content-type"]);
+    EXPECT_EQ(200, response.status_code);
+    EXPECT_EQ(ErrorCode::OK, response.error.code);
+}
+
+TEST(AnyAuthTests, SetAnySafeTest) {
+    Authentication auth = {"user", "password", AuthMode::ANYSAFE};
+    {
+        Url url{server->GetBaseUrl() + "/digest_auth.html"};
+        Session session;
+        session.SetUrl(url);
+        session.SetAuth(auth);
+        Response response = session.Get();
+        std::string expected_text{"Header reflect GET"};
+        EXPECT_EQ(expected_text, response.text);
+        EXPECT_EQ(url, response.url);
+        EXPECT_EQ(std::string{"text/html"}, response.header["content-type"]);
+        EXPECT_EQ(200, response.status_code);
+        EXPECT_EQ(ErrorCode::OK, response.error.code);
+    }
+    {
+        Url url{server->GetBaseUrl() + "/basic_auth.html"};
+        Session session;
+        session.SetUrl(url);
+        session.SetAuth(auth);
+        Response response = session.Get();
+        EXPECT_EQ(std::string{"Unauthorized"}, response.text);
+        EXPECT_EQ(url, response.url);
+        EXPECT_EQ(std::string{"text/plain"}, response.header["content-type"]);
+        EXPECT_EQ(401, response.status_code);
+        EXPECT_EQ(ErrorCode::OK, response.error.code);
+    }
+}
+
 TEST(UserAgentTests, SetUserAgentTest) {
     Url url{server->GetBaseUrl() + "/header_reflect.html"};
     UserAgent userAgent{"Test User Agent"};
@@ -1113,31 +1174,23 @@ TEST(CurlHolderManipulateTests, CustomOptionTest) {
 TEST(LocalPortTests, SetLocalPortTest) {
     Url url{server->GetBaseUrl() + "/local_port.html"};
     Session session;
-    uint16_t local_port{0};
-    uint16_t local_port_range{0};
     Response response;
-
-    // Try up to 10 times to get a free local port
-    for (size_t i = 0; i < 10; i++) {
-        session.SetUrl(url);
-        local_port = 40252 + (i * 100); // beware of HttpServer::GetPort when changing
-        local_port_range = 7000;
-        session.SetLocalPort(local_port);
-        session.SetLocalPortRange(local_port_range);
-        // expected response: body contains port number in specified range
-        // NOTE: even when trying up to 7000 ports there is the chance that all of them are occupied.
-        // It would be possible to also check here for ErrorCode::UNKNOWN_ERROR but that somehow seems
-        // wrong as then this test would pass in case SetLocalPort does not work at all
-        // or in other words: we have to assume that at least one port in the specified range is free.
-        response = session.Get();
-
-        if (response.error.code != ErrorCode::UNKNOWN_ERROR) {
-            break;
-        }
-    }
+    session.SetUrl(url);
+    uint16_t local_port{0};
+    ASSERT_NO_THROW(local_port = cpr::test::get_free_port());
+    uint16_t local_port_range{7000};
+    session.SetLocalPort(local_port);
+    session.SetLocalPortRange(local_port_range);
+    // expected response: body contains port number in specified range
+    // NOTE: even when trying up to 7000 ports there is the chance that all of them are occupied.
+    // It would be possible to also check here for ErrorCode::UNKNOWN_ERROR but that somehow seems
+    // wrong as then this test would pass in case SetLocalPort does not work at all
+    // or in other words: we have to assume that at least one port in the specified range is free.
+    response = session.Get();
 
     EXPECT_EQ(200, response.status_code);
     EXPECT_EQ(ErrorCode::OK, response.error.code);
+    errno = 0;
     // NOLINTNEXTLINE(google-runtime-int)
     unsigned long port_from_response = std::strtoul(response.text.c_str(), nullptr, 10);
     EXPECT_EQ(errno, 0);
@@ -1148,31 +1201,23 @@ TEST(LocalPortTests, SetLocalPortTest) {
 TEST(LocalPortTests, SetOptionTest) {
     Url url{server->GetBaseUrl() + "/local_port.html"};
     Session session;
-    uint16_t local_port{0};
-    uint16_t local_port_range{0};
     Response response;
-
-    // Try up to 10 times to get a free local port
-    for (size_t i = 0; i < 10; i++) {
-        session.SetUrl(url);
-        local_port = 30252 + (i * 100); // beware of HttpServer::GetPort when changing
-        local_port_range = 7000;
-        session.SetOption(LocalPort(local_port));
-        session.SetOption(LocalPortRange(local_port_range));
-        // expected response: body contains port number in specified range
-        // NOTE: even when trying up to 7000 ports there is the chance that all of them are occupied.
-        // It would be possible to also check here for ErrorCode::UNKNOWN_ERROR but that somehow seems
-        // wrong as then this test would pass in case SetLocalPort does not work at all
-        // or in other words: we have to assume that at least one port in the specified range is free.
-        response = session.Get();
-
-        if (response.error.code != ErrorCode::UNKNOWN_ERROR) {
-            break;
-        }
-    }
+    session.SetUrl(url);
+    uint16_t local_port{0};
+    uint16_t local_port_range{7000};
+    ASSERT_NO_THROW(local_port = cpr::test::get_free_port());
+    session.SetOption(LocalPort(local_port));
+    session.SetOption(LocalPortRange(local_port_range));
+    // expected response: body contains port number in specified range
+    // NOTE: even when trying up to 7000 ports there is the chance that all of them are occupied.
+    // It would be possible to also check here for ErrorCode::UNKNOWN_ERROR but that somehow seems
+    // wrong as then this test would pass in case SetLocalPort does not work at all
+    // or in other words: we have to assume that at least one port in the specified range is free.
+    response = session.Get();
 
     EXPECT_EQ(200, response.status_code);
     EXPECT_EQ(ErrorCode::OK, response.error.code);
+    errno = 0;
     // NOLINTNEXTLINE(google-runtime-int)
     unsigned long port_from_response = std::strtoul(response.text.c_str(), nullptr, 10);
     EXPECT_EQ(errno, 0);
